@@ -39,14 +39,20 @@ public:
 
   bool has_field(const Glib::ustring& field_name) const;
 
-  void add_item(const LayoutItem& item);
-  void add_item(const LayoutItem& item, guint sequence);
+  LayoutItem* add_item(const LayoutItem& item);
+  LayoutItem* add_item(const LayoutItem& item, guint sequence);
 //  void add_item(const LayoutGroup& item);
 //  void add_item(const LayoutGroup& item, guint sequence);
 
-  void change_field_item_name(const Glib::ustring& field_name, const Glib::ustring& field_name_new);
+  virtual void change_field_item_name(const Glib::ustring& table_name, const Glib::ustring& field_name, const Glib::ustring& field_name_new);
+  virtual void change_related_field_item_name(const Glib::ustring& table_name, const Glib::ustring& field_name, const Glib::ustring& field_name_new);
+  
+  virtual void change_relationship_name(const Glib::ustring& table_name, const Glib::ustring& name, const Glib::ustring& name_new);
+  virtual void change_related_relationship_name(const Glib::ustring& table_name, const Glib::ustring& name, const Glib::ustring& name_new);
 
   void remove_all_items();
+  
+  void debug(guint level = 0) const;
 
   Glib::ustring m_title;
   guint m_columns_count;
@@ -57,6 +63,8 @@ public:
   typedef std::map<int, const LayoutItem*> type_map_const_items;
   type_map_const_items get_items() const;
 
+  virtual Glib::ustring get_part_type_name() const;
+
 //Allow more efficient access: protected:
 
   type_map_items m_map_items;
